/*****************************************************************************/
/*                                                                           */
/*                              AverageFreqData()                            */
/*                                                                           */
/*		Function to do averaging of frequency data                           */
/*                                                                           */
/*		Parameters:		F_TYPE y[] = frequency data                          */
/*                                   y[0] = # data points                    */
/*									 y[1] = analysis start                   */
/*									 y[2] = analysis end                     */
/*			            int    af  = averaging factor                        */
/*                                 = # points to combine into each average   */
/*                                                                           */
/*		Return:         int        = # data points in averaged data,         */
/*									 or -1 if error                          */
/*                                                                           */
/*      Note:           All data points processed regardless of analysis     */
/*                      limits.  Zeros are treated as gaps in freq data.     */
/*						Error if af<1 or af> # original data points.         */
/*                      af=1 is OK, and results in no change in data.        */
/*                                                                           */
/*		Revision record:                                                     */
/*			04/11/97	Cloned from AverageFrequencyData() of FrequenC Lib   */
/*						Changed to use analysis limits                       */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*                                                                           */
/* (c) Copyright 1992-8  Hamilton Technical Services  All Rights Reserved    */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int AverageFreqData(F_TYPE y[], int af)
{
	int i;
	int j;
	int k=3;

	#if(0) // Original code
	int n=y[0];                                    /* # original data points */
	#endif

	#if(1) // New code 04/11/97
	int n=(int)(y[2]-y[1]+1);                      /* # original data points */
	#endif

	int num;
	double sum;

	if( (af<1) || (af>n) )
	{
		return(-1);                                                 /* error */
	}

	#if(0) // Original code
	for(i=3; i+af-1<=n+2; i+=af)
	#endif

	#if(1) // New code 04/11/97
	for(i=(int)(y[1]+2); i+af-1<=(int)(y[2]+2); i+=af)
	#endif
	{
		sum=0;
		num=af;
		for(j=0; j<af; j++)
		{
			if(*(y+i+j))                           /* don't average in a gap */
			{
				sum+=*(y+i+j);
			}                                                      /* end if */
			else
			{
				num--;
			}                                                    /* end else */
		}                                                         /* end for */
		if(num)                                         /* check if all gaps */
		{
			*(y+k++)=sum/num;
		}                                                          /* end if */
		else
		{
			*(y+k++)=0;
		}                                                        /* end else */
	}                                                             /* end for */

	#if(0) // Original code
	n=k-3;

	*y=n;
	*(y+1)=ceil(*(y+1)/af);
	*(y+2)=floor(*(y+2)/af);

	return(n);                           /* n=# data points in averaged data */
	#endif

	#if(1) // New code 04/11/97
	*y=floor(n/af);
	*(y+1)=1.0;
	*(y+2)=*y;

	return (int)*y;                            /* # data points in averaged data */
	#endif
}                                                /* end NewAverageFreqData() */

/*****************************************************************************/
