/*****************************************************************************/
/*                                                                           */
/*							  AddPSD()                                       */
/*                                                                           */
/*		Function to add freq domain noise terms                              */
/*                                                                           */
/*		Revision record:                                                     */
/*			05/03/97	Adapted from AddPSD() of STABLE_A.C                  */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*                                                                           */
/* (c) Copyright 1992-8  Hamilton Technical Services  All Rights Reserved    */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

float AddPSD(float fPSD[], int nPSDType)
{
	// Local variables
	int i;						// Index
	float fNoise[5];            // So(f) values
	float fAll;		  		    // Total So(f)

	if(nPSDType==PSD_L)
	{
		// Convert L(f) log values to So(f) numerical ones before adding
		// So{f)=2*10^[L(f)/10]
		for(i=0; i<5; i++)
		{
			if(fPSD[i])
			{
				fNoise[i]=(float)(2*(pow(10,fPSD[i]/10)));
			}
			else
			{
				fNoise[i]=0.0;
			}
		}

		// Sum noise terms
		fAll=fNoise[0]+fNoise[1]+fNoise[2]+fNoise[3]+fNoise[4];

		// Convert sum to L(f)
		if(fAll)
		{
			return (float)(10*log10(fAll/2));
		}
		else
		{
			return 0.0;
		}
	}
	else
	{
		return (float)(sqrt(fPSD[0]*fPSD[0]+fPSD[1]*fPSD[1]+fPSD[2]*fPSD[2]+
			fPSD[3]*fPSD[3]+fPSD[4]*fPSD[4]));
	}
}

/*****************************************************************************/
