/*****************************************************************************/
/*                                                                           */
/*					         AveragePhaseData()                              */
/*                                                                           */
/*		Function to average phase data by an integer factor                  */
/*                                                                           */
/*		Parameters: 	float x[] = phase data array                         */
/*                                  x[0] = # data points                     */
/*									x[1] = analysis start                    */
/*                                  x[2] = analysis end                      */
/*						int af    = averaging factor                         */
/*                                                                           */
/*		Return:         int       = # points in averaged data,               */
/*									or -1 if error                           */
/*                                                                           */
/*		Note:           All data points are processed regardless of          */
/*                      analysis limits.  Averaging phase data by            */
/*                      factor=af is done by simply using only every         */
/*                      (af)th data point.  A gap is retained if it is       */
/*                      one of the averaged points.  Error if af<1 or        */
/*                      af> # original data points.  af=1 is OK, and         */
/*                      results in no change in the data.                    */
/*                                                                           */
/*		Revision record:                                                     */
/*			04/11/97	Cloned from AveragePhaseData() of FrequenC Library   */
/*						Changed to use analysis limits                       */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*                                                                           */
/* (c) Copyright 1998   Hamilton Technical Services   All Rights Reserved    */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int AveragePhaseData(F_TYPE x[], int af)
{
	#if(0) // Original code
	int num=x[0];             /* # original phase data points to be averaged */
	#endif

	#if(1) // New code 04/11/97
	int num=(int)(x[2]-x[1]+1);    /* # original phase points to be averaged */
	int start=(int)(x[1]);                            /* analysis start point*/
	#endif

	int i;                                  /* index for averaged phase data */
			   /* i goes from 1 to ((num-1)/af)+1 averaged phase data points */
	int j;                                  /* index for original phase data */
									/* j starts at the analysis start offset */
			/* which is 1 for original phase data starting at 1st data point */
							  /* j is incremented by the averaging factor af */

	if( (af<1) || (af>num) )
	{
		return(-1);                                                 /* error */
	}

	#if(0) // Original code
	j=1;
	#endif

	#if(1) // New code 04/11/97
	j=start;
	#endif

	for(i=1; i<=((num-1)/af)+1; i++)
	{
		*(x+i+2) = *(x+j+2);                   /* 2 is the data array offset */
		j += af;
	}                                                             /* end for */

	x[0]=((num-1)/af)+1;
	x[1]=1;
	x[2]=x[0];

	return( (int) x[0]);
}                                               /* end NewAveragePhaseData() */

/*****************************************************************************/
