/***************************************************************************/
/*                                                                         */
/*                             CalcBias()                                  */
/*                                                                         */
/*		Function to calculate bias function B1(N, r=1, ), the ratio       */
/* 		of the standard variance to the Allan variance for N samples,      */
/*		zero dead-time, and integer log sigma vs log tau slope .          */
/*                                                                         */
/*      Parameters:	   int num   = # samples                               */
/*					   int mu    = sigma-tau slope (-2 to +2)              */
/*                                                                         */
/*		Return:		   float     = B1 bias function value,                 */
/*								   or -1 if error                          */
/*                                                                         */
/*		Revision Record:                                                   */
/*			11/16/90   Created                                             */
/*			12/31/91   Renamed                                             */
/*			01/05/92   Changed error code to -1                            */
/*					   Added error traps                                   */
/*			01/18/92   Edited title block                                  */
/*			02/03/96   Modified for use as Win 3.1 DLL                     */
/*			01/01/98   Changes for MS VC++ compatibility & warnings        */
/*                                                                         */
/* (c) Copyright 1990-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

float CalcBias(int num, int mu)
{
	float n=(float)num;
	float b;

	if(n<=1)
	{
		return(-1);                                          /* error code */
	}

	switch(mu)
	{
		case -2:                                    /* white or flicker PM */
		{
			b=((n*n)-1)/((float)(1.5)*n*(n-1));
			break;
		}
		case -1:                                              /* white FM */
		{
			b=1;
			break;
		}
		case 0:                                              /* flicker FM */
		{
			b=(n*(float)log(n))/(2*(n-1)*(float)log(2));
			break;
		}
		case 1:                                          /* random walk FM */
		{
			b=n/2;
			break;
		}
		case 2:                      /* frequency drift or flicker walk FM */
		{
			b=(n*(n+1))/6;
			break;
		}
		default:                                           /* unallowed mu */
		{
			b=-1;                                            /* error code */
			break;
		}
	}                                                        /* end switch */

	return(b);
}                                                        /* end CalcBias() */

/***************************************************************************/
