/*****************************************************************************/
/*                                                                           */
/*                          CountEqualTimetags()                             */
/*                                                                           */
/*      Function to count # of phase data points that have equal timetags    */
/*                                                                           */
/*      Parameters:     F_TYPE x[]      = phase array                        */
/*						F_TYPE t[]      = timetag array                      */
/*                                                                           */
/*      Return:         float           = # points removed,                  */
/*                                        or -1 if error                     */
/*                                                                           */
/*      Note: Entire data file is processed regardless of analysis limits    */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/12/03    Created from ElimEqualTimetags()                     */
/*			11/12/06	Adapted for DLL from Stable_r.c						 */
/*                                                                           */
/* (c) Copyright 2003-6  Hamilton Technical Services  All Rights Reserved    */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int CountEqualTimetags(F_TYPE x[],
	F_TYPE t[])
{
    // Local variables
	int i;							// Index
    int nNum;						// # phase data points
	int nCount=0;					// # duplicate points counted

	// Start of code
	// Set n to # phase data points
	nNum=(int)x[0];

	// Processing loop
	for(i=ARRAY_OFFSET; i<nNum+ARRAY_OFFSET-1; i++)  
	{
		// Check if two adjacent timetags are equal
		if(t[i+1]==t[i])
		{
			// Increment count
			nCount++;

			// Decrement # data points
			nNum--;
		}
	}
	
	// Done
	return nCount;
}
