/***************************************************************************/
/*                                                                         */
/*                           CalcFirstDiff()                               */
/*                                                                         */
/*      Function to calculate average of 1st differences of phase data     */
/*      Can also be used to check phase data for zero frequency due to     */
/*      zero first differences (equal adjacent phase points)               */
/*                                                                         */
/*      Parameters:     F_TYPE x[]  = array of phase data                  */
/*                                    x[0] = # phase data points           */
/*                                    x[1] = analysis start                */
/*                                    x[2] = analysis end                  */
/*                      F_TYPE *p_d = pointer to average of first          */
/*                                    differences of phase data            */
/*                                  = frequency offset of phase data       */
/*                                  = 0 if zero frequency point exists     */
/*                                                                         */
/*      Return:         int         = # analysis points,                   */
/*                                    or -1 if error                       */
/*                                                                         */
/*      Note:           Embedded gaps are treated as gaps in phase data.   */
/*                      There must be at least 1 analysis point,           */
/*                      which requires at least 2 adjacent non-gap         */
/*                      phase data points.                                 */
/*                                                                         */
/*      Revision record:                                                   */
/*          03/23/98    Created from CSD.C                                 */
/*                                                                         */
/* (c) Copyright 1998   Hamilton Technical Services  All Rights Reserved   */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int CalcFirstDiff(F_TYPE x[], F_TYPE *p_d)
{
    float num;
    double d1;
    double sum;
    int i;

    num = 0;
    sum = 0;

    for(i=(int)(x[1]+2); i<(int)(x[2]+1); i++)
    {
    if( (x[i] && x[i+1]) || (i==3 && x[4]) || ((i==x[0]+1) && x[i]) )
        /* no phase points are gaps, or 1st point with non-zero 2nd point, */
                         /* or last point with non-zero next-to-last point */
        {
            if((d1  =  x[i+1] - x[i]))
            {
                sum += d1;
                num++;
            }
            else
            {
                *p_d = 0.0;
                return(-1);
            }
        }                                                        /* end if */
    }                                                           /* end for */
    if(num>0)
    {
        *p_d = sum / num;
        return(int)num;
    }
    else
    {
        return(-1);                                               /* error */
    }
}                                                   /* end CalcFirstDiff() */

/****************************************************************************/

