/*****************************************************************************/
/*                                                                           */
/*  						CalcFreqOffset()                                 */
/*                                                                           */
/*		Function to calculate freq for phase data: x(t)=a+bt                 */
/*                                                                           */
/*		Parameters:		F_TYPE x[]  = phase data                             */
/*                                    x[0] = # data points                   */
/*			                          x[1] = analysis start                  */
/*                                    x[2] = analysis end                    */
/*      	            F_TYPE p_a  = pointer to y-intercept                 */
/*      	            F_TYPE p_b  = pointer to slope = freq offset         */
/*			            F_TYPE p_v  = pointer to fit variance                */
/*                                                                           */
/*      Return:         int         = # analysis points,                     */
/*                                    or -1 if error                         */
/*                                                                           */
/*	    Notes:	        Embedded zeros treated as gaps in phase data         */
/*						# non-gap data points must be at least 2             */
/*						and at least 3 to calc finite fit variance           */
/*                                                                           */
/*		Revision record:                                                     */
/*			02/22/97	Adapted from CalcLinFreqDrift() of FrequenC          */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*                                                                           */
/* (c) Copyright 1997-8 Hamilton Technical Services  All Rights Rserved      */                                                                         
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int CalcFreqOffset(F_TYPE x[], F_TYPE *p_a,
	F_TYPE *p_b, F_TYPE *p_v)
{
	int i;
	int num = (int)(*(x+2)-*(x+1)+1);
	double sum_x = 0;
	double sum_y = 0;
	double sum_xx = 0;
	double sum_yy = 0;
	double sum_xy = 0;

	for( i = (int)(*(x+1)+2); i <= (int)(*(x+2)+2); i++)
	{
		if( (*(x+i)) || (i==3) || (i==*(x+2)+2) )           /* check for gap */
		{
			sum_x  += i-2;
			sum_y  += *(x+i);
			sum_xx += SQR ( (float) (i-2) );           /* must cast to float */
			sum_yy += SQR ( *(x+i) );
			sum_xy += (i-2) * *(x+i);
		}
		else
		{
			num--;
		}
	}

	if(num<2)
	{
		return(-1);                                                 /* error */
	}

	*p_b = (sum_xy - ((sum_x) * (sum_y) / num));
	*p_b = *p_b / (sum_xx- ((sum_x) * (sum_x)) / num);
	*p_a = ((sum_y) / num) - (*p_b * sum_x / num);
	*p_v = 0;                           /* fit variance 0 if only 2 points */

	if(num>=3)     /* need at least 3 analysis points to calc fit variance */
	{
		*p_v = sum_yy  - (sum_y * sum_y / num);
		*p_v -= *p_b * *p_b * (sum_xx - (sum_x * sum_x / num ));
		*p_v /= (num-2);
	}

	return(num);
}

/*****************************************************************************/
