/***************************************************************************/
/*                                                                         */
/*  						CalcFreqSigma()                                */
/*                                                                         */
/*		Function to calculate Allan variance from frequency data           */
/*                                                                         */
/*		Parameters:		F_TYPE y[]    = frequency data                     */
/*                                      y[0] = # data points               */
/*			                            y[1] = analysis start              */
/*                                      y[2] = analysis end                */
/*                      F_TYPE *p_sig = pointer to Allan deviation         */
/*                                                                         */
/*		Returns:        int           = # analysis points,                 */
/*										or -1 if error                     */
/*                                                                         */
/*		Note:           Zero value treated as gap in frequency data.       */
/*						Must have at least 1 analysis point; this          */
/*						requires at least 2 adjacent non-gap frequency     */
/*                      data points.                                       */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/26/91	Changed to int returning # analysis points         */
/*			12/31/91	Renamed                                            */
/*          01/18/92    Edited title block                                 */
/*						Added error trap                                   */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int CalcFreqSigma(F_TYPE y[],
	F_TYPE *p_sig)
{
	double sum;                          /* summing variable to calc sigma */
	int i;                                            /* index for summing */
	int num = 0;                                      /* # analysis points */

	for( i = (int)(*(y+1)+2), sum = 0; i < (int)(*(y+2)+2); i++)
											   /* index goes from 1 to n-1 */
					 /* for n data points from 1 to n; data starts at y[3] */
	{
		if( *(y+i) && *(y+i+1) )           /* skip if either value is zero */
		{
			sum += SQR( *(y+i+1) - *(y+i) );
			num++;
		}                                                        /* end if */
	}                                                           /* end for */
	if(num>0)
	{
		*p_sig = ( sqrt( sum / (2.0 * num)));
		return(num);                                  /* # analysis points */
	}
	else
	{
		return(-1);                                               /* error */
	}
}                                                   /* end CalcFreqSigma() */

/***************************************************************************/
