/***************************************************************************/
/*                                                                         */
/*  						   CalcFreqStdDev()                            */
/*                                                                         */
/*		Function to calculate standard deviation from frequency data       */
/*                                                                         */
/*		Parameters:		F_TYPE y[]   = frequency data                      */
/*                                     y[0] = # data points                */
/*			                           y[1]  = analysis start              */
/*                                     y[2] = analysis end                 */
/*                      F_TYPE *p_dev = pointer to standard deviation      */
/*                                                                         */
/*		Return:         int           = # analysis points,                 */
/*										or -1 if error                     */
/*                                                                         */
/*		Note:           All zeros treated as gaps in frequency data.       */
/*						Must have at least 2 non-gap freq data points.     */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/31/91	Renamed                                            */
/*          01/18/92    Edited title block                                 */
/*			01/19/92	Added error trap                                   */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int CalcFreqStdDev(F_TYPE y[],
	F_TYPE *p_dev)
{
	double sum=0;                                      /* summing variable */
	double avg;                                 /* mean value of freq data */
	int i;                                            /* index for summing */
	int num = (int)(*(y+2)-*(y+1)+1);                 /* # analysis points */

	for(i=(int)(*(y+1)+2); i<=(int)(*(y+2))+2; i++)        /* calc average */
	{
		if(*(y+i))
		{
			sum += *(y+i);
		}
		else
		{
			num--;
		}
	}
	if((num-1)>0)                      /* check for <2 non-gap data points */
	{
		avg = sum/num;
	}
	else
	{
		return(-1);                                               /* error */
	}

	sum=0;
	for(i=(int)(*(y+1)+2); i<=(int)(*(y+2)+2); i++)       /* calc variance */
	{
		if(*(y+i))                                /* skip if value is zero */
		{
			sum += SQR(*(y+i)- avg);
		}                                                        /* end if */
	}                                                           /* end for */
	*p_dev = (sqrt(sum/(num- 1)));
	return(num);                                      /* # analysis points */
}                                                  /* end CalcFreqStdDev() */

/***************************************************************************/
