/***************************************************************************/
/*                                                                         */
/*							 CountGaps()                                   */
/*                                                                         */
/*		Function counts the number of gaps in a phase or frequency         */
/*		data file.                                                         */
/*                                                                         */
/*		Parameters:		F_TYPE z[]   = phase or frequency data array       */
/*                                     z[0] = # data points                */
/*                                     z[1] = analysis start               */
/*                                     z[2] = analysis end                 */
/*						BOOL datype  = data type: 0=phase, 1=frequency     */
/*                                                                         */
/*		Return:	        int          = # gaps in data                      */
/*                                                                         */
/*      Note:           Gaps in data are indicated by zero values.         */
/*                      Leading and trailing zeros are not counted as      */
/*                      gaps in phase data.                                */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/30/91	Created & edited                                   */
/*			12/31/91	Renamed                                            */
/*          01/18/92    Edited title block                                 */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int CountGaps(F_TYPE z[], BOOL datype)

{
	int i;                                                  /* array index */
	int count=0;                                                 /* # gaps */

	for(i=(int)(*(z+1)+3-datype); i<=(int)(*(z+2)+1+datype); i++)
					   /* start at 1st and last data points for freq data, */
									/* 2nd and next to last for phase data */
	{
		if(!*(z+i))                         /* is data point a gap (zero)? */
		{
			count++;
		}                                                        /* end if */
	}                                                           /* end for */

	return(count);
}                                                       /* end CountGaps() */

/***************************************************************************/
