/***************************************************************************/
/*                                                                         */
/*                              CalcMean()                                 */
/*                                                                         */
/* 		Function to calculate average value of phase or frequency data     */
/*                                                                         */
/*		Parameters:	    F_TYPE z[]    = phase or frequency data            */
/*                                      z[0] = # data points               */
/*			                            z[1] = analysis start              */
/*                                      z[2] = analysis end                */
/*  		            F_TYPE *p_avg = pointer to average value of data   */
/*			            BOOL datype   = data type: 0=phase, 1=frequency    */
/*                                                                         */
/*		Return:         int           = # non-gap data points,             */
/*										or -1 if error                     */
/*                                                                         */
/*	    Notes:		    All zeros treated as gaps in frequency data.       */
/*			            Embedded zeros treated as gaps in phase data.      */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/24/91	Changed to make datype a parameter rather than     */
/*						a global variable.  Made function an int return-   */
/*						ing # non-gap data points.  y[] changed to z[].    */
/*			12/31/91	Renamed                                            */
/*          01/18/92    Edited title block                                 */
/*			01/19/92	Added error trap                                   */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int CalcMean(F_TYPE z[], F_TYPE *p_avg,
	BOOL datype)
{
	double sum = 0;
	float num = 0;
	int i;

	for( i=(int)(*(z+1)+2); i<=(int)(*(z+2)+2); i++)
		                                 /* loop thru all analysis points */
	{                                                        /* skip gaps */
		if(*(z + i) || (!datype && i==3) || (!datype && i==z[0]+2))
		{
			sum += *(z+i);
			num++;
		}                                                        /* end if */
	}                                                           /* end for */
	if(num>0)
	{
		*p_avg = sum/num;
		return(int)num;                    /* return # non-gap data points */
	}
	else
	{
		return(-1);                                               /* error */
	}
}                                                        /* end CalcMean() */

/***************************************************************************/
