/***************************************************************************/
/*                                                                         */
/*								CalcNormalProb()                           */
/*                                                                         */
/*		Function to calculate the cumulative normal distribution,          */
/*		the area under the normal or Gaussian distrubution to the          */
/*		left of the normal variable x.                                     */
/*                                                                         */
/*      Reference:     Collected Algorithms from CACM, Vol. I, #209,       */
/*                     D. Ibbetson and E. Brothers, 1963.                  */
/*                                                                         */
/*	    Parameter:	   float x = normal variable                           */
/*                                                                         */
/*		Return:        float   = p(x) = normal probability value           */
/*									                                       */
/*		Revision record:                                                   */
/*			12/30/91   Created                                             */
/*			12/31/91   Renamed                                             */
/*			01/18/92	Edited title block                                 */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*																		   */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

float CalcNormalProb(float x)

{
	double w, y, z;

	if (x == 0.0)
	{
		z = 0.0;
	}                                                            /* end if */
	else
	{
		y = fabs(x) / 2.0;
		if (y >= 3.0)
		{
			z = 1.0;
		}                                                        /* end if */
		else
		{
			if (y < 1.0)
			{
				w = y * y;
				z = ((((((((0.000124818987 * w
				-.001075204047) * w + .005198775019) * w
				-.019198292004) * w + .059054035642) * w
				-.151968751364) * w + .319152932694) * w
				-.531923007300) * w + .797884560593) * y * 2.0;
			}                                                    /* end if */
			else
			{
				y = y - 2.0;
				z = (((((((((((((-.000045255659 * y
				+.000152529290) * y - .000019538132) * y
				-.000676904986) * y + .001390604284) * y
				-.000794620820) * y - .002034254874) * y
				+.006549791214) * y - .010557625006) * y
				+.011630447319) * y - .009279453341) * y
				+.005353579108) * y - .002141268741) * y
				+.000535310849) * y + .999936657524;
			}                                                  /* end else */
		}                                                      /* end else */
	}                                                          /* end else */

	if (x > 0.0)
	{
		return (float)((z + 1.0) / 2.0);
	}                                                            /* end if */
	else
	{
		return (float)((1 - z) / 2.0);
	}                                                          /* end else */
}                                                    /* end CalcNormProb() */

/***************************************************************************/
