/***************************************************************************/
/*                                                                         */
/*					         CalcSecondDiff()                              */
/*                                                                         */
/*		Function to calculate average of 2nd differences of phase data     */
/*                                                                         */
/*		Parameters: 	F_TYPE x[]  = array of phase data                  */
/*                                    x[0] = # phase data points           */
/*                                    x[1] = analysis start                */
/*                                    x[2] = analysis end                  */
/*		                F_TYPE *p_d = pointer to average of second         */
/*                                    differences of phase data            */
/*                                  = frequency drift of phase data        */
/*                                                                         */
/*		Return:         int         = # anlaysis points,                   */
/*                                    or -1 if error                       */
/*                                                                         */
/*      Note:           Embedded gaps are treated as gaps in phase data.   */
/*						There must be at least 1 analysis point,           */
/*                      which requires at least 3 adjacent non-gap         */
/*                      phase data points.                                 */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/29/91	Created                                            */
/*			12/31/91	Renamed                                            */
/*          01/18/92    Edited title                                       */
/*			01/19/92	Added d parameter for result, changed return to    */
/*                      int = # analysis points, added error trap          */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int CalcSecondDiff(F_TYPE x[], F_TYPE *p_d)
{
	float num;
	double d1;
	double d2;
	double sum;
	int i;

	num = 0;
	sum = 0;

	for(i=(int)(x[1]+2); i<=(int)x[2]; i++)
	{
	if((x[i] && x[i+1] && x[i+2]) || (i==3 && x[4] && x[5]) \
								  || (x[i+1] && x[i] && i==x[2]))
 /* no phase points are gaps, or 1st point with non-zero 2nd & 3rd points, */
 /* or last point with non-zero next-to-last & next-to-next-to-last points */
		{
			d1  =  x[i+1] - x[i];
			d2  =  x[i+2] - x[i+1];
			sum += d2 -d1;
			num++;
		}                                                        /* end if */
	}                                                           /* end for */
	if(num>0)
	{
		*p_d = sum / num;
		return(int)num;
	}
	else
	{
		return(-1);                                              /* error */
	}
}                                                  /* end CalcSecondDiff() */

/***************************************************************************/
