/*****************************************************************************/
/*                                                                           */
/*                           DateConv()                                      */
/*                                                                           */
/*      Function to convert month & year to day of week, DOY and MJD,        */
/*      plus # days in month.                                                */
/*                                                                           */
/*      Calling program sets month and year.  1st day of month is assumed.   */
/*      Function sets corresponding day of week, day of year, MJD and        */
/*      # days in month.                                                     */
/*                                                                           */
/*      Uses date functions from Hammer library.                             */
/*                                                                           */
/*      Parameters:                                                          */
/*          int  lpnMonth          pointer to month (January=1)              */
/*          int  lpnDaysInMonth    pointer to # days in month                */
/*          int  lpnYear           pointer to year (e.g. 1995)               */
/*          int  lpnDOW            pointer to day of week (Sunday=0)         */
/*          int  lpnDOY            pointer to day of year                    */
/*          long lplnMJD           pointer to Modified Julian Date           */
/*                                                                           */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*      Revision record:                                                     */
/*          03/30/96    Adapted from date_conv() of SCRN_CAL.C               */
/*          04/08/97    Fixed bug in century leap year logic                 */
/*          07/18/97    Changed to new date function to avoid Hammer Library */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"                        /* FrequenC Library header file */

void DateConv(int *lpnMonth,
	int *lpnDaysInMonth, int *lpnYear, int *lpnDOW, int *lpnDOY, long *lplnMJD)
{
    static int sum[] = { 0, 31, 59, 90, 120, 151, 181, 212,
                          243, 273, 304, 334, 365 };
    static int num_days[] = {31, 28, 31, 30, 31, 30, 31, 31,
                          30, 31, 30, 31};
    // LOCAL VARIABLES
    int month;
    int year;
    int dow;                         /* day of week: 0=Sunday ... 6=Saturday */
    int day=1;                                      /* day of month always 1 */
    int doy;                                                  /* day of year */
    int leap=0;                                            /* leap year flag */
    long int gdate;                                        /* Gregorian date */
    long int jdate;                                          /* Julian day # */
    long int mjd;                                     /* Modified Julian Day */

    // INITIALIZATIONS
    month=*lpnMonth;
    year=*lpnYear;

    // DATE CONVERSIONS
    gdate=MakeDate(month, day, year);
    BreakDate(gdate, &month, &day, &year);
    dow=DayOfWeek(gdate);

    doy=sum[month-1]+day;

    if( ((year % 4 == 0) && (year % 100 != 0)) || (year % 400 == 0) )
    {
        leap=1;
        if(month>2)
        {
            doy++;
        }                                                          /* end if */
    }                                                              /* end if */

    jdate=DateToJulian(gdate);
    mjd=jdate-2400001L;

    // PASS RESULTS
    *lplnMJD=mjd;
    *lpnDOW=dow;
    *lpnDOY=doy;

    if(month!=2)
    {
        leap=0;
    }                                                              /* end if */

    *lpnDaysInMonth=num_days[month-1]+leap;
}                                                      /* end date_convert() */

/*****************************************************************************/

