/*****************************************************************************/
/*                                                                           */
/*                              DayOfWeek()                                  */
/*                                                                           */
/*      Function to find the day of the week for a given Gregorian date      */
/*                                                                           */
/*      Note: Calls Brkdate() above                                          */
/*                                                                           */
/*      Parameters: long    gdate   Gregorian date (yyyymmdd)                */
/*                                                                           */
/*      Return:     int             Day of week (0=Sunday, 6=Saturday)       */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/17/97    Cloned from dayofwk() of Hammer Library              */
/*                      Changed error return to -1                           */
/*                      Modified for 4-digit year from BreakDate()           */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"                        /* FrequenC Library header file */

int DayOfWeek(long gdate)
{
    // Local variables
    int a, b, mo, da, yr;
    static int mos[12] = { 0,3,3,6,1,4,6,2,5,0,3,5 };

    BreakDate(gdate, &mo, &da, &yr);

    // Convert 4-digit year into 2-digit year
    // yr=yr % 100;  // Only OK 1900-1999
    yr=yr-1900;      // Better; OK 1900-2099

    if ( mo<1 || mo>12 || da<1 || da>31 || yr<0 )
    {
        return (-1);    /* error - bad date */
    }

    a = (yr/4) + yr + da + mos[mo-1];
    b = (a % 7) + 1;

    if (mo<=2 && yr!=0 && (yr % 4)==0)
    {
        b = (b==0 ? 6 : b) - 1;
    }

    b = (b==0 ? 7 : b) - 1;

    return (b); /* return day of week (0-6) */
}

/*****************************************************************************/

