/*****************************************************************************/
/*                                                                           */
/*                              DateToJulian()                               */
/*                                                                           */
/*      Function to convert Gregorian date to Julian day number              */
/*                                                                           */
/*      Parameters: long    gdate   Gregorian date (yyyymmdd)                */
/*                                                                           */
/*      Return:     long    jdate   Julian day number                        */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/17/97    Cloned from datjul() of Hammer Library               */
/*                      Changed error return to -1                           */
/*                      Modified to use 4-digit year return from BreakDate() */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"                        /* FrequenC Library header file */

long DateToJulian(long gdate)
{
    // Local variables
    long jdate; /* Julian Day Number for given date */
    int mo, da, yr, c, ya;

    if (gdate<=0L || gdate==19000000L)  /* if zero or negative, return -1 */
    {
        return (-1L); /* error */
    }

    BreakDate(gdate, &mo, &da, &yr);

    if (mo>2)
    {
        mo-=3;
    }
    else
    {
        mo+=9;
        yr--;
    }

    c=yr/100;
    ya=yr%100;
    jdate=(146097L*c)/4L + (1461L*ya)/4L + (153L*mo+2L)/5L + da + 1721119L;

    return (jdate);
}

/*****************************************************************************/

