/***************************************************************************/
/*                                                                         */
/*							  FindMinMax                                   */
/*                                                                         */
/*		Function to find min and max of phase or frequency data            */
/*                                                                         */
/*		Parameters:	    F_TYPE z[]    = frequency data                     */
/*                                      z[0] = # data points               */
/*			                            z[1] = analysis start              */
/*                                      z[2] = analysis end                */
/*      	            F_TYPE *p_min = pointer to minimum data value      */
/*      	            F_TYPE *p_max = pointer to maximum data value      */
/*			            BOOL   datype = data type: 0=phase, 1=frequency    */
/*                                                                         */
/*	    Notes:	        All zero treated as gaps in frequency data.    	   */
/*			            Embedded zeros treated as gaps in phase data.      */
/*						min & max set to 0 if no non-gap data points.      */
/*                                                                         */
/*      Return:         int            = # non-gap data points             */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/26/91	Changed to make datype a parameter rather than     */
/*						a global variable.  Made function an int return-   */
/*						ing # non-gap data points.  y[] changed to z[].    */
/*			12/31/91	Renamed; min & max arguments reversed              */
/*			01/18/92	Edited title block                                 */
/*			01/19/92	Changed to min=max=0 if no non-gap data points     */
/*			02/20/92	Rewritten to eliminate use of MAXFLOAT             */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int FindMinMax(F_TYPE z[], F_TYPE *p_min,
	F_TYPE *p_max, BOOL datype)
{
	int i;                                                        /* index */
	int num=0;                                    /* # non-gap data points */
	BOOL flag=FALSE;           /* flag to indicate 1st non-gap point found */

	*p_max = 0;                               /* initialize max & min to 0 */
	*p_min = 0;            /* they will remain 0 if no non-gap data points */

	for( i = (int)(*(z+1)+2); i <= (int)(*(z+2)+2); i++)
	{
		if(*(z + i) || (!datype && i==3) || (!datype && i==z[0]+2))
		{
			if(flag)
			{
				if( *(z + i) > *p_max )
				{
					*p_max = *(z + i);
				}                                                /* end if */
				if( *(z + i) < *p_min )
				{
					*p_min = *(z + i);
				}                                                /* end if */
			}                                                    /* end if */
			else                                 /* lst non-gap data point */
			{
				*p_max = *(z + i);
				*p_min = *(z + i);
				flag = TRUE;
			}                                                  /* end else */
			num++;
		}                                                        /* end if */
	}                                                           /* end for */

	return(num);
}                                                      /* end FindMinMax() */

/***************************************************************************/
