/*****************************************************************************/
/*                                                                           */
/*                              HistoCalc()                                  */
/*                                                                           */
/*      Function to calculate histogram from frequency data                  */
/*      Parameters:                                                          */
/*          y[]         = analysis data;         y[0] = # data points        */
/*                        y[1] = analysis start; y[2] = analysis end         */
/*          bins[]      = histogram bin values                               */
/*          hist[]      = histogram counts                                   */
/*          y_max       = maximum y[] value                                  */
/*          num_bins    = # histogram bins                                   */
/*                                                                           */
/*      Returns nothing (void)                                               */
/*                                                                           */
/*      Revision record:                                                     */
/*          12/28/96    Adapted from Stable/DOS histo_calc() of STAB_F15.C   */
/*          12/29/96    Up and running                                       */
/*          12/30/96    Added gap handling (Histo never had that!)           */
/*			03/20/03	Adapted for FrequenC DLL                             */
/*						Added BOOL bDataType argument                        */
/*                                                                           */
/* (c) Copyright 19922003 Hamilton Technical Services  All Rights Reserved   */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

void HistoCalc(F_TYPE y[], float bins[],
	float hist[], F_TYPE *y_max, int num_bins, BOOL bDataType)
{
    // Local variables
    int i;                                                  /* general index */
    int j;                                                      /* bin index */
    int points=(int)(y[2]-y[1]+1);                      /* # analysis points */
    int offset=(int)(y[1]+2);                 /* index of 1st analysis point */

    // Calc histogram of y[] values from [offset] to [points]
    // Using bins[] from [0] to [num_bins]
    // Counts of # data values/bin go into histogrm[] from [0] to [num_bins-1]
    // y_max keeps track of the largest bin count for the normal curve fit

    *y_max=0.0;

    for(i=offset; i<offset+points; i++)
    {
        if( y[i] || (bDataType==PHASE_DATA && i==3) ||
                    (bDataType==PHASE_DATA && i==y[0]+2) )
        {
            for(j=0; j<num_bins; j++)
            {
                if(y[i]<=bins[j+1])
                {
                    hist[j]++;
                    if(hist[j]>*y_max)
                    {
                        *y_max=hist[j];
                    }
                    break;
                }
            }
        }
    }
}

/***************************************************************************/


