/*****************************************************************************/
/*                                                                           */
/*                              JulianToDate()                               */
/*                                                                           */
/*      Function to convert Julian day number to Gregorian date              */
/*                                                                           */
/*      Parameters: long    jdate   Julian day number                        */
/*                                                                           */
/*      Return:     long            Gregorian date (yyyymmdd)                */
/*                                                                           */
/*      Revision record:                                                     */
/*          07/17/97    Cloned from juldat() of Hammer Library               */
/*                      Changed error code to -1                             */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"                        /* FrequenC Library header file */

long JulianToDate(long jdate)
{
    extern long int makdate();
    long int gdate; /* Gregorian Date (yyyymmdd) for given Julian Day */
    int mo, da, yr;
    long int td, tm, ty;

    if (jdate<=0L)  /* if zero or negative, return -1 */
    {
        return (-1L);
    }

    jdate-=1721119L;
    ty=(4L*jdate-1L)/146097L;
    jdate=4L*jdate - 1L - 146097L*ty;
    td=jdate/4L;

    jdate=(4L*td+3)/1461L;
    td=4L*td + 3L - 1461L*jdate;
    td=(td+4L)/4L;

    tm=(5L*td - 3L)/153L;
    td=5L*td - 3L - 153L*tm;
    td=(td+5L)/5L;

    ty=100L*ty + jdate;
    if (tm<10L)
    {
        tm+=3L;
    }
    else
    {
        tm-=9L, ty++;
    }

    da=(int) td; mo=(int) tm; yr=(int) ty;
    gdate=MakeDate(mo, da, yr);

    return(gdate);
}

/*****************************************************************************/

