/****************************************************************************/
/*                                                                          */
/*                             MJDToDate()                                  */
/*                                                                          */
/*		Function for MJD to date conversion                                 */
/*                                                                          */
/*      Parameters:                                                         */
/*          long mjd     modified Julian day # to be converted into date    */
/*			int	*day	 pointer to day of date to be found from MJD        */
/*		    int *month   pointer to month of date to be found from MJD      */
/*          int *year    pointer to year of date to be found from MJD       */
/*                                                                          */
/*      Return: 														    */
/*			none (void)                                                     */
/*                                                                          */
/*      Example:                                                            */
/*		    November 11, 1992 is MJD 48937.                                 */
/*                                                                          */
/*		Function revision record:                                           */
/*			11/11/92	Created                                             */
/*			11/28/92	Adapted for FrequenC Library                        */
/*			02/03/96	Changed constant 679019 to L                        */
/*			02/03/96	Modified for use as Win 3.1 DLL                     */
/*			01/01/98	Changes for MS VC++ compatibility & warnings        */
/*                                                                          */
/*  (c) Copyright 1992-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                          */
/****************************************************************************/

#include "frequenc.h"                               /* FrequenC header file */

void MJDToDate(long mjd, int *day,
		int *month, int *year)
{
	mjd+=679019L;
	*year=(int)((mjd-122.1)/365.25);
	*month=(int)((mjd-(long)(365.25**year))/30.6001);
	*day=(int)(mjd-(int)(365.25**year)-(int)(30.6001**month));

	if(*month<14)
	{
		*month-=1;
	}                                                             /* end if */
	else
	{
		*month-=13;
	}                                                           /* end else */

	if(*month<3)
	{
		*year+=1;
	}                                                             /* end if */

}                                                        /* end MjdToDate() */

/****************************************************************************/
