/*****************************************************************************/
/*                                                                           */
/*                              MJDtoDOY()                                   */
/*                                                                           */
/*      Function to convert long integer MJD to DOY                          */
/*                                                                           */
/*      Parameters:                                                          */
/*                  long    nMJD    MJD value                                */
/*                                                                           */
/*      Return:     int     nDOY    Day of year                              */
/*                                                                           */
/*      Dependencies:                                                        */
/*                  MJDToDate()                                              */
/*                                                                           */
/*      Revision record:                                                     */
/*          03/20/02    Created                                              */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"                        /* FrequenC Library header file */

int MJDtoDOY(long lnMJD)
{
    // Local variables
    // Ints
    int nYear;
    int nDOY;
    int nMonth;
    int nDay;
    static int nSum[] = { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304,
        334, 365 };

    // Start of code
    // Convert integer MJD to date
    MJDToDate(lnMJD, &nDay, &nMonth, &nYear);

    // Convert data to DOY
    nDOY=nSum[nMonth-1]+nDay;
    if((nYear%4==0 && nYear%100!=0) || nYear%400==0)
    {
        if(nMonth>2)
        {
            nDOY++;
        }
    }

    // Return DOY
    return nDOY;
}

/****************************************************************************/

