/***************************************************************************/
/*                                                                         */
/* 							 NormalizeData()                               */
/*																		   */
/*		Function to normalize phase or freq data by removing mean value    */
/*                                                                         */
/*		Parameters:     F_TYPE z[]  = phase or freq data                   */
/*                                    z[0] = # data points                 */
/*			                          z[1] = analysis start                */
/*                                    z[2] = analysis end                  */
/*      	            F_TYPE avg  = average value to be removed          */
/*			            int datype  = data type: 0=phase, 1=frequency      */
/*                                                                         */
/*      Return:         int         = # non-gap data points (may be 0)     */
/*                                                                         */
/*	    Notes:	        All zeros treated as gaps in frequency data        */
/*			            Embedded zeros are gaps in phase data              */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/24/91	Added datype parameter & int return value          */
/*			12/26/91	Changed avg parameter from pointer to value        */
/*			12/31/91	Renamed                                            */
/*			01/18/92	Edited title block                                 */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int NormalizeData(F_TYPE z[], F_TYPE avg,
	BOOL datype)
{
	int i;
	int n=0;

	for( i = (int)(*(z+1)+2); i <= (int)(*(z+2)+2); i++)
	{
		if(*(z+i) || (!datype && i==3) || (!datype && i==z[0]+2))
		{
			*(z+i) -=  avg;
			n++;
		}                                                        /* end if */
	}                                                           /* end for */
	return(n);
}                                                   /* end NormalizeData() */

/***************************************************************************/
