/***************************************************************************/
/*                                                                         */
/*                              RoundAxes()                                */
/*                                                                         */
/*      Still another function to find plot scale                          */
/*      Ref: Quinn-Curtis S&E Tools IPC-TC-006 SEGRAPH.C                   */
/*                                                                         */
/*      Parameters:  realtype *a1   =   pointer to data min input          */
/*                                      becomes scale min output           */
/*                   realtype *a2   =   pointer to data max input          */
/*                                      becomes scale max output           */
/*                   realtype *tics =   pointer to tics size output        */
/*                                                                         */
/*      Return:        None (void)                                         */
/*                                                                         */
/*      Revision record:                                                   */
/*          03/10/02    Copied and adapted                                 */
/*          03/12/02    Added log 0 trap                                   */
/*			03/19/03	Adapted for FrequenC DLL                           */
/*                                                                         */
/***************************************************************************/

// FrequenC header
#include "frequenc.h"

// Local function prototypes
F_TYPE log10x(F_TYPE realnum);
int NumExp(F_TYPE realnum);
F_TYPE PowerCalc(F_TYPE realnum, F_TYPE power);

// RoundAxes function
void  RoundAxes(F_TYPE *a1, F_TYPE *a2,
    F_TYPE *tics)
{
   F_TYPE dr1, dr2, px2, pc2;
   int di1, di2, digits, a2neg, a1neg;

   a1neg = (*a1 < 0);
   a2neg = (*a2 > 0);
   if (NumExp(*a2) > NumExp(*a1))
     px2 = NumExp(*a2) - 1;
   else
     px2 = NumExp(*a1) - 1;
   pc2 = PowerCalc(10.0,px2);
   dr2 = (*a2) / pc2;
   dr1 = (*a1) / pc2;

   di2 = (int)ceil(dr2 + 0.000001+(dr2-dr1)*0.05);
   if ((di2 > 0) && (dr2 <= 0.0)) di2 = 0;

   di1 = (int)floor(dr1 - 0.000001- (dr2-dr1)*0.05);
   if ((di1 < 0) && (dr1 >= 0.0)) di1 = 0;

   if ( abs(di2) < 10 )
      di2 = di2 + a2neg;
   else
     if ( abs(di2) < 60 )
    di2 = ((di2 / 5) + a2neg ) * 5;
     else
       di2 = ((di2 / 10) + a2neg) * 10;

   if ( abs(di1) < 60 )
    di1 = ((di1 / 5) - a1neg) * 5;
   else
    di1 = ((di1 / 10) - a1neg) * 10;

   *a1 = di1 * pc2;
   *a2 = di2 * pc2;
   digits = abs(di2 - di1);
   if ( digits < 10 )
      *tics =  1.0;
   else
     if ( digits < 20 )
       *tics = 2.0;
     else
       if ( digits < 40 )
     *tics = 5.0;
       else
     if ( digits < 80 )
       *tics = 10.0;
     else
       if ( digits < 100 )
         *tics = 20.0;
       else
         if ( digits < 151 )
           *tics = 20.0;
         else
           if ( digits < 200 )
         *tics = 50.0;
           else
         *tics = 100.0;

   *tics = *tics * pc2 / 10.0;
}

// Local subroutines adapted from SELIB.C
F_TYPE log10x(F_TYPE realnum)
{  F_TYPE fret;
    // Avoid log 0
    if(realnum==0.0)
    {
        realnum=1e-99;
    }
   fret = log10(realnum);
   return(fret);
}

int NumExp(F_TYPE realnum)
{
   int fret;
   fret = (int)floor(log10x(fabs(realnum)));
   return(fret);
}

F_TYPE PowerCalc(F_TYPE realnum, F_TYPE power)
{
   F_TYPE fret;
   fret = pow(realnum,power);
   return(fret);
}

/***************************************************************************/

