/*****************************************************************************/
/*                                                                           */
/*                             ReverseData()                                 */
/*                                                                           */
/*      Function to reverse order of phase or frequency data                 */
/*                                                                           */
/*      Parameters:     F_TYPE z[]  = phase or freq data                     */
/*                                    z[0] = # data points                   */
/*                                    z[1] = analysis start                  */
/*                                    z[2] = analysis end                    */
/*                                                                           */
/*      Return:         void          None                                   */
/*                                                                           */
/*      Revision record:                                                     */
/*          03/01/08    Created & working                                    */
/*						Tested AOK even & odd # points, phase or freq data   */
/*						Used in scale function                               */
/*                                                                           */
/* (c) Copyright 2008  Hamilton Technical Services  All Rights Reserved      */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

void ReverseData(F_TYPE z[])
{
    // Local variables
	int i;                                                        /* z index */
	int start;                                       /* analysis start index */
    int num;                                                /* # data points */
	F_TYPE temp;                        /* temporary data value for swapping */

	// Initializations
	start=(int)z[1]-1;                               /* analysis start index */
	num=(int)(z[2]-z[1]+1);                   /* set num = # analysis points */

	// Loop to reverse data
	for(i=0; i<num/2; i++)
	{
		// Swap pair of data points
		temp=z[start+i+ARRAY_OFFSET];
		z[start+i+ARRAY_OFFSET]=z[start+num-1-i+ARRAY_OFFSET];
		z[start+num-1-i+ARRAY_OFFSET]=temp;
	}
}
