/*****************************************************************************/
/*                                                                           */
/* 						   RemoveDiffusionFreqDrift()                        */
/*														    				 */
/*		Function to remove diffusion frequency drift y(t) = a + b(t+c)      */
/*                                                                           */
/*		Parameters:		F_TYPE y[] = frequency data                          */
/*                                   y[0] = # frequency data points          */
/*			                         y[1] = analysis start                   */
/*                                   y[2] = analysis end                     */
/*                      F_TYPE a   = a term of diffusion fit                 */
/*                      F_TYPE b   = b term of diffusion fit                 */
/*                      F_TYPE c   = c term of diffusion fit                 */
/*                                                                           */
/*      Return:         int        = # data points processed                 */
/*                                                                           */
/*	    Notes:          All zeros treated as gaps in frequency data.         */
/*		                Use function CalcDiffusionFreqDrift() to             */
/*                      calculate diffusion fit parameters a and b.          */
/*                                                                           */
/*		Revision record:                                                     */
/*			06/11/97	Created from first RemoveDiffusionFreqDrift()        */
/*			12/09/97	Added to FrequenC Library                            */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*                                                                           */
/* (c) Copyright 1997-8 Hamilton Technical Services   All Rights Reserved    */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int RemoveDiffusionFreqDrift(F_TYPE y[],
	F_TYPE a, F_TYPE b, F_TYPE c)
{
	int i;                                                          /* index */
	int num=0;                                         /* # points processed */

	for(i = (int)(*(y+1)+2); i <= (int)(*(y+2)+2); i++)   /* analysis limits */
	{
		if(*(y+i))                                          /* check for gap */
		{
			*(y+i) -=  a + (b * sqrt((double) (i-2)+c));     /* remove drift */
			num++;                                        /* increment count */
		}                                                          /* end if */
	}                                                             /* end for */

	return(num);                                /* return # points processed */
}                                       /* end NewRemoveDiffusionFreqDrift() */

/*****************************************************************************/
