/*****************************************************************************/
/*                                                                           */
/* 							 RemoveFreqOffset()                              */
/*																		     */
/*		Function to remove freq offset from phase data: x(t) = a + bt        */
/*                                                                           */
/*		Parameters:		F_TYPE x[] = phase data                              */
/*                                   x[0] = # phase data points              */
/*			                         x[1] = analysis start                   */
/*                                   x[2] = analysis end                     */
/*                      F_TYPE a   = intercept of linear fit                 */
/*                      F_TYPE b   = slope of linear fit = freq offset       */
/*						BOOL bA    = switch for constant term removal        */
/*                                                                           */
/*      Return:         int        = # data points processed                 */
/*                                                                           */
/*	    Notes:          All embedded zeros treated as gaps in phase data.    */
/*		                Use function CalcFreqOffset() to calculate linear    */
/*                      fit parameters a and b.                              */
/*                                                                           */
/*		Revision record:                                                     */
/*			02/22/97	Adapted from RemoveLinFreqDrift() of FrequenC        */
/*			02/27/97	Added BOOL bA parameter                              */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*                                                                           */
/* (c) Copyright 1997-8 Hamilton Technical Services  All Rights Reserved     */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int RemoveFreqOffset(F_TYPE x[], F_TYPE a,
	F_TYPE b, BOOL bA)
{
	int i;                                                          /* index */
	int num=0;                                         /* # points processed */

	// To avoid compiler warning if paramater a isn't used
	a=a;

	for(i = (int)(*(x+1)+2); i <= (int)(*(x+2)+2); i++)   /* analysis limits */
	{
		if( (*(x+i)) || (i==3) || (i==*(x+2)+2) )           /* check for gap */
		{
			if(bA)
			{
				// Remove slope and intercept - make average zero
				*(x+i) -=  a + (b * (i-3));    /* remove slope and intercept */
			}
			else
			{
				// Remove slope only
				*(x+i) -=  b * (i-2);                        /* remove slope */
			}
			num++;                                        /* increment count */
		}
	}

	return(num);                                /* return # points processed */
}

/*****************************************************************************/
