/***************************************************************************/
/*                                                                         */
/* 							 RemoveLinFreqDrift()                          */
/*																		   */
/*		Function to remove linear frequency drift y(t) = a + bt            */
/*                                                                         */
/*		Parameters:		F_TYPE y[] = frequency data                        */
/*                                   y[0] = # frequency data points        */
/*			                         y[1] = analysis start                 */
/*                                   y[2] = analysis end                   */
/*                      F_TYPE a   = intercept of linear fit               */
/*                      F_TYPE b   = slope of linear fit                   */
/*                                                                         */
/*      Return:         int        = # data points processed               */
/*                                                                         */
/*	    Notes:          All zeros treated as gaps in frequency data.       */
/*		                Use FrequenC function CalcLinFreqDrift() to        */
/*                      calculate linear fit parameters a and b.           */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/26/91	Changed to int returning # data points processed   */
/*						Changed slope & intercept from pointers to values  */
/*			12/30/91	Changed to include internal call to drift_calc()   */
/*                      with slope and intercept parameters removed        */
/*			12/31/91	Renamed                                            */
/*			01/18/92	Edited title block                                 */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int RemoveLinFreqDrift(F_TYPE y[],
	F_TYPE a, F_TYPE b)
{
	int i;                                                        /* index */
	int num=0;                                       /* # points processed */

	for(i = (int)(*(y+1)+2); i <= (int)(*(y+2)+2); i++) /* analysis limits */
	{
		if(*(y+i))                                        /* check for gap */
		{
			*(y+i) -=  a + (b * (i-2));                    /* remove drift */
			num++;                                      /* increment count */
		}                                                        /* end if */
	}                                                           /* end for */

	return(num);                              /* return # points processed */
}                                              /* end RemoveLinFreqDrift() */

/***************************************************************************/
