/***************************************************************************/
/*                                                                         */
/* 							 RemoveLogFreqDrift()                          */
/*																		   */
/*		Function to remove frequency drift using log model                 */
/*		                      y(t) = a*ln(bt+1)+c, where:                  */
/*			                  y(t) = fractional frequency                  */
/*					          t    = time                                  */
/* 					          a    = multiplicative term                   */
/*					          b    = log time term                         */
/*					          c    = constant term                         */
/*                                                                         */
/*		Parameters:		F_TYPE y[] = frequency data                        */
/*                                   y[0] = # frequency data points        */
/*			                         y[1] = analysis start                 */
/*                                   y[2] = analysis end                   */
/*      	            F_TYPE a   = log fit parameter a                   */
/*      	            F_TYPE b   = log fit parameter b                   */
/*			            F_TYPE c   = log fit parameter c                   */
/*                                                                         */
/*      Return:         int        = # data points processed               */
/*                                                                         */
/*	    Note:           All zeros treated as gaps in frequency data	       */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/26/91	Changed to int returning # data points processed   */
/*						Changed a, b & c from pointers to values           */
/*			12/31/91	Renamed                                            */
/*			01/18/92	Edited title block                                 */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int RemoveLogFreqDrift(F_TYPE y[],
	F_TYPE a, F_TYPE b,	F_TYPE c)
{
	int i;                                                        /* index */
	int num=0;                                       /* # points processed */

	for(i = (int)(*(y+1)+2); i <= (int)(*(y+2)+2); i++) /* analysis limits */
	{
		if(*(y+i))                                        /* check for gap */
		{
			*(y+i) -=  c + (a * (log((b * (i-2))+1)));     /* remove drift */
			num++;                                      /* increment count */
		}                                                        /* end if */
	}                                                           /* end for */

	return(num);                              /* return # points processed */
}                                              /* end RemoveLogFreqDrift() */

/***************************************************************************/
