/*****************************************************************************/
/*                                                                           */
/* 						   RemoveQuadraticDrift()                            */
/*															    		     */
/*		Function to remove frequency drift from phase data                   */
/*		by removing quadratic fit x(t) = a + bt + ct                        */
/*                                                                           */
/*		Parameters:		F_TYPE x[] = phase data                              */
/*                                   x[0] = # phase data points              */
/*			                         x[1] = analysis start                   */
/*                                   x[2] = analysis end                     */
/*                      F_TYPE a  =  offset term                             */
/*                      F_TYPE b  =  linear term                             */
/*                      F_TYPE c  =  drift term                              */
/*                                                                           */
/*      Return:         int       = # data points processed                  */
/*                                                                           */
/*    	Notes:          Embedded zeros treated as gaps in phase data.        */
/*		                Use quadratic() to calculate quadratic fit           */
/*						parameters a, b and c.                               */
/*                                                                           */
/*		Revision record:                                                     */
/*			02/24/97	Adapted from RemoveQuadraticDrift()                  */
/*						Corrected error in gap recognition                   */
/*			01/01/98	Changes for MS VC++ compatibility & warnings         */
/*			08/25/06	Brought into Stable_r.c from RQD2.C of               */
/*						FrequenC library to correct long-standing error      */
/*						Index i does not start from 0, so it can't be used   */
/*						directly as coefficient multiplier                   */
/*						The multiplier at the 1st point S/B 1 (not zero)     */
/*						Note: The FrequenC Lib RLFD.C function for removal   */
/*						of linear frequency drift is OK as-is.               */
/*			11/12/06	Updated in DLL from Stable_r.c						 */
/*                                                                           */
/* (c) Copyright 1997-2006 Hamilton Technical Services  All Rights Reserved  */
/*                                                                           */
/*****************************************************************************/

#include "frequenc.h"

int RemoveQuadraticDrift(F_TYPE x[],
	F_TYPE a, F_TYPE b,	F_TYPE c)

{
	int i;                                                          /* index */
	int num=0;                                         /* # points processed */

	for( i = (int)(*(x+1)+2); i <= (int)(*(x+2)+2); i++)  /* remove quad fit */
	{
		if( *(x+i) || i==*(x+1)+2 || i==*(x+2)+2 )          /* check for gap */
		{
			#if(0) // Original code
			*(x+i) -=  a + (b * i) + (c * i * i);       /* remove quad terms */
			#endif

			#if(1) // New code 08/24/06
			*(x+i) -=  a+(b*(i-2))+(c*(i-2)*(i-2));     /* remove quad terms */
			#endif

			num++;                                        /* increment count */
		}
	}
	return(num);
}

/*****************************************************************************/
