/***************************************************************************/
/*                                                                         */
/* 							 ScaleData()                                   */
/*																		   */
/*		Function to scale phase or frequency data by multipling by a       */
/*		multiplier constant and adding an addend constant:                 */
/*      z[i] = addend + z[i] * multiplier                                  */
/*                                                                         */
/*      Parameters:		F_TYPE z[]  = data array                           */
/*                                    z[0] = # data points                 */
/*			                          z[1] = analysis start                */
/*                                    z[2] = analysis end                  */
/*      	            F_TYPE add  = addend                               */
/*      	            F_TYPE mult = multiplier                           */
/*			            int datype  = data type: 0=phase, 1=frequency      */
/*                                                                         */
/*	    Notes:          All zeros treated as gaps in frequency data	       */
/*			            Embedded zeros are gaps in phase data              */
/*                                                                         */
/*      Return:         int          = # non-gap values processed          */
/*                                                                         */
/*		Revision record:                                                   */
/*			12/16/91	Created                                            */
/*			12/26/91	Changed to int returning # data points processed   */
/*						Added datype parameter; changed array to z[]       */
/*						Changed add and mult to values not pointers        */
/*			12/31/91	Renamed                                            */
/*			01/18/92	Edited title block                                 */
/*			02/03/96	Modified for use as Win 3.1 DLL                    */
/*			01/01/98	Changes for MS VC++ compatibility & warnings       */
/*                                                                         */
/* (c) Copyright 1991-8  Hamilton Technical Services  All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

#include "frequenc.h"

int ScaleData(F_TYPE z[], F_TYPE add,
	F_TYPE mult, BOOL datype)
{
	int i;
	int num=0;

	for(i = (int)(*(z+1)+2); i <= (int)(*(z+2)+2); i++)
	{
		if(*(z+i) || (!datype && i==3) || (!datype && i==z[0]+2))
		{
			*(z+i) *=  mult;                /* multiply data by multiplier */
			*(z+i) +=  add;                          /* add addend to data */
			num++;
		}                                                        /* end if */
	}                                                           /* end for */

	return(num);
}                                                       /* end ScaleData() */

/***************************************************************************/
