/***************************************************************************/
/*                                                                         */
/*                          FrequenC.h                                     */
/*                                                                         */
/*      Header file for FrequenC Library                                   */
/*      To be included in all FrequenC source files                        */
/*		This version is for Linux                                          */
/*                                                                         */
/*      Revision record:                                                   */
/*          12/24/91    Created                                            */
/*          12/25/91    More drafting                                      */
/*          12/26/91    Ditto                                              */
/*          12/29/91    Ditto                                              */
/*          12/30/91    Ditto                                              */
/*          12/31/91    Functions renamed                                  */
/*          01/04/92    All CalcDegFree() parameters made ints             */
/*          01/18/92    Added a & b parameters to RemoveLinFreqDrift()     */
/*                      Added a, b & c params to RemoveQuadraticDrift()    */
/*          01/19/92    Changed CalcSecondDiff() to int and added *p_d     */
/*          01/22/92    Changed order of parameters in FindPlotScale()     */
/*          01/26/92    Added #defines for PSD and SIG types               */
/*          02/17/92    Changed min & max params in FindPlotScale()        */
/*          02/18/92    Added #defines for noise types                     */
/*                      Eliminated unneeded #defines & #include files      */
/*          02/20/92    Eliminated #include <values.h> -- new FMM.C        */
/*          11/28/92    Added prototypes for the following new functions:  */
/*                          CalcHadamardDev()                              */
/*                          CalcGreenhallModSigma()                        */
/*                          CalcThreePointDrift()                          */
/*                          CalcBisectionDrift()                           */
/*                          FindFreqOutliers()                             */
/*                          MJDToDate()                                    */
/*                          DateToMJD()                                    */
/*          04/03/93    Added stdio.h include file                         */
/*          02/03/96    Modified for use as Win 3.1 DLL                    */
/*          01/01/98    Added EXPORT macro for Win 16/32 portability       */
/*          03/08/03    Changed CalcPhaseModSigma() prototype              */
/*                      Changed ConvPhaseToFreq() prototype                */
/*          03/09/03    Brought in many functions from Stable_r.c          */
/*          03/11/03    Added date functions                               */
/*			03/14/03	New FrequenC dll working with Stable32             */
/*			11/12/06	Added new functions for Version 3.0:               */
/*							Theo1()                                        */
/*							Theo1Bias()                                    */
/*                          Theo1EDF()                                     */
/*                          Theo1BiasToAlpha()                             */
/*                          CountEqualTimetags()                           */
/*                          CombinedEDF()                                  */
/*                          GetMJD()                                       */
/*                          AutocorrelationCalc()                          */
/*                          ACFNoiseID()                                   */
/*                      Added time.h to include files                      */
/*			12/31/06	Added NewTheo1() to Version 3.0  Note that both    */
/*						Theo1() and NewTheo1() are needed.  The latter     */
/*						has optional bias removal and calls the former.    */
/*			03/03/07	Fixed error in ConvDomain()                        */
/*          12/05/17	Adapted for Linux                                  */
/*                                                                         */
/* (c)Copyright 1991-2017 Hamilton Technical Services All Rights Reserved  */
/*                                                                         */
/***************************************************************************/

/* Standard C include files */
#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include <time.h>

/* definitions */
#define SQR( a)  ((a) * (a))                         /* macro for squaring */
#define MIN(a,b) (((a)<(b))?(a):(b))                  /* macro for minimum */
#define MAX(a,b) (((a)>(b))?(a):(b))                  /* macro for maximum */
#define FALSE 0                                              /* BOOL value */
#define TRUE 1                                               /* BOOL value */
#define F_TYPE double                           /* can be changed to float */
#define BOOL int                                              /* BOOL type */
#define PHASE 0                                 /* datype=0 for phase data */
#define PHASE_DATA 0                            /* datype=0 for phase data */
#define FREQ 1                              /* datype=1 for frequency data */
#define FREQ_DATA 1                         /* datype=1 for frequency data */
#define PSD_Y 1                                    /* type=1 for Sy(f) PSD */
#define PSD_X 2                                    /* type=2 for Sx(f) PSD */
#define PSD_P 3                                    /* type=3 for S(f) PSD */
#define PSD_L 4                                    /* type=4 for L(f)  PSD */
#define SIG_Y 5                                        /* type=5 for y() */
#define MODSIG_Y 6                                 /* type=6 for Mod y() */
#define SIG_X 7                                        /* type=7 for x() */
#define W_PM 2                                /* noise type=2 for white PM */
#define F_PM 1                              /* noise type=1 for flicker PM */
#define W_FM 0                                /* noise type=0 for white FM */
#define F_FM -1                            /* noise type=-1 for flicker FM */
#define RW_FM -2                       /* noise type=-2 for random walk FM */
#define ARRAY_OFFSET 3                         /* Offset to 1st data point */

// Sigma Types
#define NORMAL_SIGMA           0
#define OVERLAPPING_SIGMA      1
#define MODIFIED_SIGMA         2
#define TIME_SIGMA             3
#define HADAMARD_SIGMA         4
#define OVERLAPHAD_SIGMA       5
#define TOTAL_SIGMA            6
#define MODTOTAL_SIGMA         7
#define TIMETOTAL_SIGMA        8
#define HADTOTAL_SIGMA         9
#define TIERMS_SIGMA           10
#define MTIE_SIGMA             11
#define THEO1_SIGMA            12

/* FrequenC function prototypes */ 

// Variance functions
int CalcFreqSigma(F_TYPE y[], F_TYPE *p_sig);
int CalcFreqStdDev(F_TYPE y[],
    F_TYPE *p_dev);
int CalcFreqModSigma(F_TYPE y[],
    F_TYPE *p_modsig, int m);
int CalcFreqOverlapSigma(F_TYPE y[],
    F_TYPE *p_sig, int m);
int CalcFastModSigma(F_TYPE x[],
    F_TYPE *p_modsig, F_TYPE tau, int m);
int CalcPhaseStdDev(F_TYPE x[],
    F_TYPE *p_dev, F_TYPE tau);
int CalcPhaseModSigma(F_TYPE x[],
	F_TYPE *p_sig, F_TYPE tau, int m);
int CalcPhaseOverlapSigma(F_TYPE x[],
    F_TYPE *p_sig, F_TYPE tau, int m);
int CalcPhaseSigma(F_TYPE x[],
    F_TYPE *p_sig, F_TYPE tau);
int CalcPhaseHadamardDev(F_TYPE x[],
    F_TYPE *p_dev, F_TYPE tau);
int CalcGreenhallModSigma(F_TYPE x[],
    F_TYPE *p_sig, F_TYPE tau, int m);
int CalcHadamardDev(F_TYPE x[],
    F_TYPE *p_dev, F_TYPE tau);
int CalcFreqOverlapHadamardDev(F_TYPE y[],
    F_TYPE *p_sig, int m);
int CalcFreqOverlapSigma(F_TYPE y[],
    F_TYPE *p_sig, int m);
int CalcMTIE(F_TYPE fX[], F_TYPE *fMTIE,
    int nAF, BOOL *bAbort, BOOL bProgress,
    void *ProgressFunction(int nPercentDone, char *szMessage));
int CalcPhaseOverlapHadamardDev(F_TYPE x[],
    F_TYPE *p_dev, F_TYPE tau, int m);
int CalcPhaseStdDev(F_TYPE x[],
    F_TYPE *p_dev, F_TYPE tau);
int TotvarCalc(F_TYPE fX[], F_TYPE *fTotDev,
    F_TYPE fTau, int nAF, void *lpfnProgress);
int CalcFreqHadamardDev(F_TYPE y[],
    F_TYPE *p_dev);
int ModTotvarCalc(F_TYPE fX[],
    F_TYPE *fMTDev, F_TYPE fTau, int nAF, BOOL *bAbort, BOOL bProgress,
    void *ProgressFunction(int nPercentDone, char *szMessage));
int TIErms(F_TYPE fX[], F_TYPE *fTIE,
    int nAF);
int HadTotvarCalc(F_TYPE fY[], F_TYPE *fHTDev,
    int nAF, BOOL *bAbort, BOOL bProgress,
    void *ProgressFunction(int nPercentDone, char *szMessage));
float Theo1(F_TYPE x[], F_TYPE *p_sig,
	F_TYPE tau, int m, BOOL *bAbort, BOOL bProgress,
	void (*ProgressFunction)(int nPercentDone, char *szMessage));

// EDF functions
float EDF(int nBeta, int nAvgFactor, int nNum);
float CalcDegFree(int a, int n, int m);
float HadamardEDF(int N, int m, int b);
float HadTotvarEDF(int nAlpha,
    float fRatio);
float TotvarEDF(int nAlpha, float fRatio);
float ModTotvarEDF(int nAlpha,
    float fRatio);
float Theo1EDF(int nAlpha, int nNum,
	float fRatio);
float CombinedEDF(int N, int m, int a,
	int d, int F, int S, int v);

// Bias functions
float CalcRatio(int alpha, int num,
    float b);
float CalcBias(int num, int mu);
float CalcBias1(int n, float r, float mu);
float CalcBias2(float r, float mu);
float CalcBias3(int m, float r, float mu);
float TotvarBias(int nAlpha, float fRatio);
float HadTotvarBias(int nAlpha);
float CalcHadamardB1(int num, int mu);
float CalcStarB1(F_TYPE fData[],
    BOOL bDataType, F_TYPE fTau, int nAF);
float ModTotvarBias(int nAlpha);
float Theo1Bias(int nAlpha, float fTau);

// Drift functions
int CalcLinFreqDrift(F_TYPE y[],
    F_TYPE *p_a, F_TYPE *p_b, F_TYPE *p_v);
int CalcLogFreqDrift(F_TYPE y[],
    F_TYPE *p_a, F_TYPE *p_b, F_TYPE *p_c, F_TYPE *p_v);
int RemoveLinFreqDrift(F_TYPE y[], F_TYPE a,
    F_TYPE b);
int RemoveLogFreqDrift(F_TYPE y[], F_TYPE a,
    F_TYPE b, F_TYPE c);
int RemoveQuadraticDrift(F_TYPE x[],
    F_TYPE a, F_TYPE b, F_TYPE c);
int CalcQuadraticDrift(F_TYPE x[], F_TYPE t,
    F_TYPE *p_a, F_TYPE *p_b, F_TYPE *p_c, F_TYPE *p_v);
int RemoveDiffusionFreqDrift(F_TYPE y[],
    F_TYPE a, F_TYPE b, F_TYPE c);
float CalcThreePointDrift(F_TYPE x[]);
float CalcBisectionDrift(F_TYPE y[]);
int CalcDiffusionFreqDrift(F_TYPE y[],
    F_TYPE *p_a, F_TYPE *p_b, F_TYPE *p_c, F_TYPE *p_v);
int CalcSecondDiff(F_TYPE x[], F_TYPE *p_d);
  
// Misc statistics functions
int CalcMean(F_TYPE z[], F_TYPE *p_avg,
    BOOL datype);
int FindMinMax(F_TYPE z[], F_TYPE *p_min,
    F_TYPE *p_max, BOOL datype);
int FindMedian(F_TYPE fData[],
    BOOL bDataType, F_TYPE *pfMedian);
int MedDev(F_TYPE y[], float *p_mad);
void HistoCalc(F_TYPE y[], float bins[],
	float hist[], F_TYPE *y_max, int num_bins, BOOL bDataType);
int AutocorrelationCalc(F_TYPE fZ[],
	float a[], int nLags, int nAF, BOOL bType, BOOL bMethod, BOOL bZero);
   
// Plot scale functions 
int FindPlotScale(F_TYPE min, F_TYPE max,
    F_TYPE *p_scale_min, F_TYPE *p_scale_max);
int BasScale (double XMin, double XMax,
	int N, double* SMin, double* Step);
void RoundAxes(F_TYPE *a1, F_TYPE *a2,
    F_TYPE *tics);
   
// Data conversion functions
int ConvFreqToPhase(F_TYPE y[], F_TYPE x[],
    F_TYPE tau, BOOL do_norm);
int ConvPhaseToFreq(F_TYPE x[], F_TYPE y[],
    F_TYPE tau, BOOL z); 
int NewConvFreqToPhase(F_TYPE y[],
    F_TYPE x[], F_TYPE tau, BOOL do_norm);
int ConvPhaseToFreqUsingTimetags(F_TYPE x[],
	F_TYPE y[], F_TYPE t[], F_TYPE scale, F_TYPE *avg, BOOL z);
   
// Domain conversion functions
float AddSigma(float fSigma[]);
float AddPSD(float fPSD[], int nPSDType);
int CalcDomain(float *p_h, float z,
    float tau, float f, float v, float fh, int type, int alpha, int n);
int ConvDomain(float h, float *p_z,
	float tau, float f, float v, float fh, int type, int alpha, int n);
    
// Gap handling functions
int FillGaps(F_TYPE z[], BOOL datype);
int FillFloatGaps(float z[],
	BOOL datype);
int CountGaps(F_TYPE z[], BOOL datype);
int CountEqualTimetags(F_TYPE x[],
	F_TYPE t[]);

// Probability functions
float CalcInvChiSqr(float p, float df);
float CalcNormalProb(float x);
float CalcChiSqrProb(float x, float df);

// Utility functions
int CheckFrequenC(void);

// Data manipulation functions
int AverageFreqData(F_TYPE y[],
    int avg_factor);
int AveragePhaseData(F_TYPE x[], int a);
int ScaleData(F_TYPE z[], F_TYPE add,
    F_TYPE mult, BOOL datype);
int NormalizeData(F_TYPE z[], F_TYPE avg,
    BOOL datype);
    
// Frequency offset functions
int RemoveFreqOffset(F_TYPE x[], F_TYPE a,
    F_TYPE b, BOOL bA);
int CalcFreqOffset(F_TYPE x[], F_TYPE *p_a,
    F_TYPE *p_b, F_TYPE *p_v);
int CalcFirstDiff(F_TYPE x[], F_TYPE *p_d);
    
// Outlier functions
int FindFreqOutliers(F_TYPE y[],
    float sig_mult, BOOL remove_flag);

// Noise ID functions   
int NoiseID(int nNum, int nSigmaType,
    int nAvgFactor, float fBW, float fRatio);
int Theo1BiasToAlpha(float fBias,
	int nAvgFactor);
int ACFNoiseID(F_TYPE fZ[], BOOL bDataType,
	int nAF, float *fR1, float *fAlpha, int *nAlpha, int nDmax, int nDmin);

// Noise generation functions
int GenNoise(int n_pts, double x[],
	float Q_d, float b,	int *idum, int add_flag);

// Spectral functions
int MultiTaperSpectrumCalc(F_TYPE y[],
	float data[], float freq[], float dt, int num_points, float npi,
	int nwin, int kind, int inorm, int win_type, int p_type,
	float corr_factor, BOOL bDataType);
int SpectrumCalc(F_TYPE y[], float xdata[],
	float ydata[], float tau, int n, int win_num, int win_type,
	int phase_noise_type, float correction_factor, int af, int data_type,
	int bZeroPad);

// Date functions
long DateToMJD(int day, int month,
    int year);
void DateConv(int *lpnMonth,
    int *lpnDaysInMonth, int *lpnYear, int *lpnDOW, int *lpnDOY,
    long *lplnMJD);
int DayOfWeek(long gdate);
void BreakDate(long gdate, int *mo,
    int *da, int *yr);
long DateToJulian(long gdate);
long MakeDate(int mo, int da, int yr);
long JulianToDate(long jdate);
int MJDtoGPS(long MJD);
int MJDtoDOY(long lnMJD);
void MJDToDate(long mjd, int *day,
    int *month, int *year);
double GetMJD(void);

/***************************************************************************/
